==> mc-stats-1.0.7.tgz: package/test/test.js <==
const mc = require("../app.js");

const main = async () => {
  // mc.mccentral("kitpvp", "leaderboard").then(r => console.log(r));
  // mc.munchymc("badboyhalo", "player").then(r => console.log(r));
  // mc.hypixelPlayer("Dinnerbone").then(r => console.log(r));
  // mc.blocksmc("_IPlozSawdadawd". "player").then(r => console.log(r));
  // mc.funcraft("nathan818").then(r => console.log(r));
  // mc.mineplex("xeiu").then(r => console.log(r));
  // mc.manacube("KaiYara12").then(r => console.log(r));
  // mc.minesaga("doitnowornever").then(r => console.log(r));
  // mc.gommehd("YouBetterGoAfk").then(r => console.log(r));
  // mc.timolia("XxSt3gsfanxX").then(r => console.log(r));
  // mc.minemen("Cleid").then(r => console.log(r));
  // mc.veltpvp("DissTracks").then(r => console.log(r));
  // mc.universocraft("ImOvee_Idk").then(r => console.log(r));
  // mc.hypixelBoosters().then(r => console.log(r));
  // mc.minemen("NiceTryEfe").then(r => console.log(r));
  // mc.hivemc("Gooogle_it", "profile").then(r => console.log(r));
  // mc.hivemc("jonas2246", "SG").then(r => console.log(r));
  // mc.hivemc("Tutle", "BP").then(r => console.log(r));
  // mc.hivemc("Ingola", "CAI").then(r => console.log(r));
  // mc.hivemc("Endlen", "CR").then(r => console.log(r));
  // mc.hivemc("kaiurii", "DR").then(r => console.log(r));
  // mc.hivemc("Limimin", "HB").then(r => console.log(r));
  // mc.hivemc("Limimin", "HB").then(r => console.log(r));
  // mc.hivemc("Caro", "HERO").then(r => console.log(r));
  // mc.hivemc("Spenken", "HIDE").then(r => console.log(r));
  // mc.hivemc("AslanThePro", "OITC").then(r => console.log(r));
  // mc.hivemc("Demon2921", "SP").then(r => console.log(r));
  // mc.hivemc("HeinzBeans", "TIMV").then(r => console.log(r));
  // mc.hivemc("Rinjani", "SKY").then(r => console.log(r));
  // mc.hivemc("Mcae", "DRAW").then(r => console.log(r));
  // mc.hivemc("Varsel", "SLAP").then(r => console.log(r));
  // mc.hivemc("Mackan__", "EF").then(r => console.log(r));
  // mc.hivemc("Conga_", "MM").then(r => console.log(r));
  // mc.hivemc("ShooterGHP", "GRAV").then(r => console.log(r));
  // mc.hivemc("Bgbros", "RR").then(r => console.log(r));
  // mc.hivemc("RageStateOfMind", "GNT").then(r => console.log(r));
  // mc.hivemc("iiAnass", "SGN").then(r => console.log(r));
  // mc.hivemc("Fcssy", "BD").then(r => console.log(r));
  // mc.hivemc("IDontExquseYou", "SPL").then(r => console.log(r));
  // mc.hivemc("Marleeey", "MIMV").then(r => console.log(r));
  // mc.hivemc("HappyStateOfMind", "BED").then(r => console.log(r));
  // mc.wynncraft("player", "1MCRocker").then(r => console.log(r));
  // mc.wynncraft("guild", "Imperial").then(r => console.log(r));
};

main();

==> mc-stats-1.0.8.tgz: package/test/test.js <==
const mc = require("../app.js");

const main = async () => {
  // mc.mccentral("kitpvp", "leaderboard").then(r => console.log(r));
  // mc.munchymc("badboyhalo", "player").then((r) => console.log(r));
  // mc.hypixelPlayer("Dinnerbone").then(r => console.log(r));
  // mc.blocksmc("_IPlozSawdadawd". "player").then(r => console.log(r));
  // mc.funcraft("nathan818").then(r => console.log(r));
  // mc.mineplex("xeiu").then(r => console.log(r));
  // mc.manacube("KaiYara12").then(r => console.log(r));
  // mc.minesaga("doitnowornever").then(r => console.log(r));
  // mc.gommehd("YouBetterGoAfk").then(r => console.log(r));
  // mc.timolia("Flycofx").then((r) => console.log(r));
  // mc.minemen("Cleid").then(r => console.log(r));
  // mc.veltpvp("DissTracks").then(r => console.log(r));
  // mc.universocraft("ImOvee_Idk").then(r => console.log(r));
  // mc.hypixelBoosters().then(r => console.log(r));
  // mc.minemen("NiceTryEfe").then(r => console.log(r));
  // mc.hivemc("Gooogle_it", "profile").then(r => console.log(r));
  // mc.hivemc("jonas2246", "SG").then(r => console.log(r));
  // mc.hivemc("Tutle", "BP").then(r => console.log(r));
  // mc.hivemc("Ingola", "CAI").then(r => console.log(r));
  // mc.hivemc("Endlen", "CR").then(r => console.log(r));
  // mc.hivemc("kaiurii", "DR").then(r => console.log(r));
  // mc.hivemc("Limimin", "HB").then(r => console.log(r));
  // mc.hivemc("Limimin", "HB").then(r => console.log(r));
  // mc.hivemc("Caro", "HERO").then(r => console.log(r));
  // mc.hivemc("Spenken", "HIDE").then(r => console.log(r));
  // mc.hivemc("AslanThePro", "OITC").then(r => console.log(r));
  // mc.hivemc("Demon2921", "SP").then(r => console.log(r));
  // mc.hivemc("HeinzBeans", "TIMV").then(r => console.log(r));
  // mc.hivemc("Rinjani", "SKY").then(r => console.log(r));
  // mc.hivemc("Mcae", "DRAW").then(r => console.log(r));
  // mc.hivemc("Varsel", "SLAP").then(r => console.log(r));
  // mc.hivemc("Mackan__", "EF").then(r => console.log(r));
  // mc.hivemc("Conga_", "MM").then(r => console.log(r));
  // mc.hivemc("ShooterGHP", "GRAV").then(r => console.log(r));
  // mc.hivemc("Bgbros", "RR").then(r => console.log(r));
  // mc.hivemc("RageStateOfMind", "GNT").then(r => console.log(r));
  // mc.hivemc("iiAnass", "SGN").then(r => console.log(r));
  // mc.hivemc("Fcssy", "BD").then(r => console.log(r));
  // mc.hivemc("IDontExquseYou", "SPL").then(r => console.log(r));
  // mc.hivemc("Marleeey", "MIMV").then(r => console.log(r));
  // mc.hivemc("HappyStateOfMind", "BED").then(r => console.log(r));
  // mc.wynncraft("player", "1MCRocker").then(r => console.log(r));
  // mc.wynncraft("guild", "Imperial").then(r => console.log(r));
};

main();
